# TermType

Type of the term. If the value of this field is `TERMED`, the first term has a predefined duration based on the value of the `period` field. If the value of this field is `EVERGREEN`, the term does not have a predefined duration. 

## Enum

* `TERMED` (value: `'TERMED'`)

* `EVERGREEN` (value: `'EVERGREEN'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


